@@ -1,19 +1,3 @@
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Utilities for testing libraries using Aloe.
 """
@@ -22,12 +6,11 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
 # pylint:disable=redefined-builtin
 from builtins import super
 # pylint:enable=redefined-builtin
-standard_library.install_aliases()
 
+import io
 import os
 import sys
 import tempfile
@@ -44,27 +27,40 @@ from aloe.registry import (
     STEP_REGISTRY,
 )
 from aloe.runner import Runner
+from aloe.utils import PY3, TestWrapperIO
+
+# When the outer Nose captures output, it's a different type between Python 2
+# and 3.
+if PY3:
+    CAPTURED_OUTPUTS = (io.StringIO,)
+else:
+    # io.StringIO is an alias to cStringIO.StringIO, which is a function and
+    # not a type
+    import StringIO  # pylint:disable=import-error
+    CAPTURED_OUTPUTS = (
+        type(io.StringIO()),
+        StringIO.StringIO,
+    )
 
 
 @contextmanager
 def _in_directory(directory):
     """
-    A context manager to run the payload in a specified directory, with it
-    added to the module search path and all modules from it removed from
-    sys.modules upon exit.
+    A context manager to run the payload in a specified directory.
+
+    On exit, all modules that were imported from this directory are removed
+    from sys.modules.
     """
 
     directory = os.path.abspath(directory)
     last_wd = os.getcwd()
 
-    sys.path.insert(0, directory)
     os.chdir(directory)
 
     try:
         yield
     finally:
         os.chdir(last_wd)
-        sys.path.remove(directory)
 
         # Unload modules which are loaded from the directory
         unload_modules = []
@@ -90,9 +86,9 @@ def _in_directory(directory):
             if not path.startswith(unload_path_prefix):
                 continue
 
-            # Does its name match what would it be if it was? Consider two
-            # directories, foo/ and foo/bar on sys.path, foo/bar/baz.py
-            # might have been loaded from either.
+            # Does its name match what would it be if the module was really
+            # imported from here? Consider two directories, 'foo' and 'foo/bar'
+            # on sys.path, foo/bar/baz.py might have been loaded from either.
             path = path[len(unload_path_prefix):]
             if module_name == path_to_module_name(path):
                 unload_modules.append(module_name)
@@ -186,6 +182,8 @@ class TestGherkinPlugin(GherkinPlugin):
 class TestRunner(Runner):
     """
     A test test runner to store information about the tests run.
+
+    :param stream: a stream to write the output into (optional)
     """
 
     def gherkin_plugin(self):
@@ -199,8 +197,18 @@ class TestRunner(Runner):
 
     def __init__(self, *args, **kwargs):
         self.tests_run = []
+        self.stream = kwargs.pop('stream')
+
         super().__init__(*args, **kwargs)
 
+    def makeConfig(self, *args, **kwargs):
+        config = super().makeConfig(*args, **kwargs)
+
+        if self.stream:
+            config.stream = self.stream
+
+        return config
+
 
 class FeatureTest(unittest.TestCase):
     """
@@ -217,40 +225,84 @@ class FeatureTest(unittest.TestCase):
     def run_feature_string(self, feature_string):
         """
         Run the specified string as a feature.
+
+        The feature will be created as a temporary file in the 'features'
+        directory relative to the current directory. This ensures the steps
+        contained within would be found by the loader.
         """
 
-        with tempfile.NamedTemporaryFile(suffix='.feature', dir=os.getcwd()) \
+        if not os.path.isdir('features'):
+            raise ValueError(
+                "Features directory not found in {0}".format(os.getcwd()))
+
+        with tempfile.NamedTemporaryFile(suffix='.feature', dir='features') \
                 as feature_file:
             feature_file.write(feature_string.encode())
             feature_file.flush()
             return self.run_features(os.path.relpath(feature_file.name))
 
-    def run_features(self, *features):
+    def run_features(self, *features, **kwargs):
         """
         Run the specified features.
         """
 
+        # named keyword args and variable positional args aren't supported on
+        # Python 2
+        verbosity = kwargs.get('verbosity')
+        stream = kwargs.get('stream')
+        force_color = kwargs.get('force_color', False)
+
+        if stream is None and isinstance(sys.stdout, CAPTURED_OUTPUTS):
+            # Don't show results of running the inner tests if the outer Nose
+            # redirects output
+            stream = TestWrapperIO()
+
         CALLBACK_REGISTRY.clear(priority_class=PriorityClass.USER)
         STEP_REGISTRY.clear()
         world.__dict__.clear()
 
-        return TestRunner(exit=False,
-                          argv=['aloe'] + list(features))
+        argv = ['aloe']
 
-    def assert_feature_success(self, *features):
+        if verbosity:
+            argv += ['--verbosity', str(verbosity)]
+
+        if force_color:
+            argv += ['--color']
+
+        argv += list(features)
+
+        result = TestRunner(exit=False, argv=argv, stream=stream)
+        result.captured_stream = stream
+        return result
+
+    def assert_feature_success(self, *features, **kwargs):
         """
         Assert that the specified features can be run successfully.
         """
 
-        result = self.run_features(*features)
-        assert result.success
-        return result
+        result = self.run_features(*features, **kwargs)
+        try:
+            assert result.success
+            return result
+        except AssertionError:
+            if isinstance(result.captured_stream, CAPTURED_OUTPUTS):
+                print("--Output--")
+                print(result.captured_stream.getvalue())
+                print("--END--")
+            raise
 
-    def assert_feature_fail(self, *features):
+    def assert_feature_fail(self, *features, **kwargs):
         """
         Assert that the specified features fail when run.
         """
 
-        result = self.run_features(*features)
-        assert not result.success
-        return result
+        result = self.run_features(*features, **kwargs)
+        try:
+            assert not result.success
+            return result
+        except AssertionError:
+            if isinstance(result.captured_stream, CAPTURED_OUTPUTS):
+                print("--Output--")
+                print(result.captured_stream.getvalue())
+                print("--END--")
+            raise
