@@ -1,19 +1,3 @@
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2015> Alexey Kotlyarov <a@koterpillar.com>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test callbacks.
 """
@@ -22,8 +6,6 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
 import operator
 from functools import reduce  # pylint:disable=redefined-builtin
@@ -37,6 +19,9 @@ from aloe.testing import (
     in_directory,
 )
 
+# Pylint cannot infer the attributes on world
+# pylint:disable=no-member
+
 
 @in_directory('tests/callbacks_app')
 class CallbackTest(FeatureTest):
@@ -65,17 +50,17 @@ class CallbackTest(FeatureTest):
 
         self.assert_feature_success('features/step_callbacks.feature')
 
-        self.assertEquals(world.step_names, self.name_sequence([
+        self.assertEqual(world.step_names, self.name_sequence([
             'Given I emit a step event of "A"',
             'And I emit a step event of "B"',
             'Then the step event sequence should be "{[A]}{[B]}{["',
         ]))
 
         # Check step.testclass
-        self.assertEquals(len(world.step_testclasses), 3)
+        self.assertEqual(len(world.step_testclasses), 3)
         for testclass in world.feature_testclasses:
             self.assertTrue(issubclass(testclass, TestCase))
-            self.assertEquals(testclass.__name__, "Step callbacks")
+            self.assertEqual(testclass.__name__, "Step callbacks")
 
     def test_example_callbacks(self):
         """
@@ -84,7 +69,7 @@ class CallbackTest(FeatureTest):
 
         self.assert_feature_success('features/example_callbacks.feature')
 
-        self.assertEquals(world.example_names, self.name_sequence([
+        self.assertEqual(world.example_names, self.name_sequence([
             'Scenario: Example callbacks in a simple scenario, steps=3',
             'Outline: Example callbacks in a scenario with examples ' +
             '(event=C), steps=2',
@@ -106,13 +91,13 @@ class CallbackTest(FeatureTest):
             'Feature callbacks (test)',
         )
 
-        self.assertEquals(world.feature_names, self.name_sequence(names))
+        self.assertEqual(world.feature_names, self.name_sequence(names))
 
         # Check feature.testclass
-        self.assertEquals(len(world.feature_testclasses), 2)
+        self.assertEqual(len(world.feature_testclasses), 2)
         for feature_name, testclass in zip(names, world.feature_testclasses):
             self.assertTrue(issubclass(testclass, TestCase))
-            self.assertEquals(testclass.__name__, feature_name)
+            self.assertEqual(testclass.__name__, feature_name)
 
     def test_all_callbacks(self):
         """
@@ -202,6 +187,13 @@ class CallbackTest(FeatureTest):
 
         self.assert_feature_success('features/behave_as.feature')
 
+    def test_behave_as_ru(self):
+        """
+        Test 'behave_as' on a non-English feature.
+        """
+
+        self.assert_feature_success('features/behave_as_ru.feature')
+
     def test_step_failed(self):
         """
         Test the value of step.failed.
@@ -227,7 +219,7 @@ class MultipleDirectoriesCallbackTest(FeatureTest):
 
         self.assert_feature_success('one/features/check_started.feature')
 
-        self.assertEquals(world.started_callbacks_one, {
+        self.assertEqual(world.started_callbacks_one, {
             'one': True,
             'two': True,
         })
@@ -240,12 +232,12 @@ class MultipleDirectoriesCallbackTest(FeatureTest):
 
         self.assert_feature_success()
 
-        self.assertEquals(world.started_callbacks_one, {
+        self.assertEqual(world.started_callbacks_one, {
             'one': True,
             'two': True,
         })
 
-        self.assertEquals(world.started_callbacks_two, {
+        self.assertEqual(world.started_callbacks_two, {
             'one': True,
             'two': True,
         })
