@@ -1,20 +1,4 @@
 # -*- coding: utf-8 -*-
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test Russian language parsing.
 """
@@ -23,14 +7,11 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-# pylint:disable=redefined-builtin
-from builtins import str
-# pylint:enable=redefined-builtin
-from future import standard_library
-standard_library.install_aliases()
+# pylint:disable=redefined-builtin,wildcard-import,unused-wildcard-import
+from builtins import *
+# pylint:enable=redefined-builtin,wildcard-import,unused-wildcard-import
 
 from nose.tools import assert_equal
-from aloe.languages import Language
 from aloe.parser import Feature
 
 SCENARIO = u"""
@@ -55,7 +36,7 @@ SCENARIO_OUTLINE1 = u'''
     | имя  | возраст |
     | Вася | 22      |
     | Петя | 30      |
-'''  # noqa
+'''
 
 FEATURE = u'''
 Функционал: Деление чисел
@@ -74,38 +55,21 @@ FEATURE = u'''
 
 def parse_scenario(string, language=None):
     """Parse a scenario, prefixing it with a feature header."""
-    feature = u"""
+    feature_str = u"""
     Функция: parse_scenario
     """
-    feature += string
-    feature = Feature.from_string(feature, language=language)
+    feature_str += string
+    feature = Feature.from_string(feature_str, language=language)
 
     return feature.scenarios[0]
 
 
-def test_language_russian():
-    """
-    Language: RU -> Language class supports russian through code "ru"
-    """
-
-    lang = Language('ru')
-
-    assert_equal(lang.code, u'ru')
-    assert_equal(lang.name, u'Russian')
-    assert_equal(lang.native, u'Русский')
-    assert_equal(lang.FEATURE, u'Функционал')
-    assert_equal(str(lang.SCENARIO),
-                 '{"Сценарий" ^ "Структура сценария"}')
-    assert_equal(lang.EXAMPLES, u'Примеры')
-
-
 def test_scenario_ru_from_string():
     """
     Language: RU -> Scenario.from_string
     """
 
-    lang = Language('ru')
-    scenario = parse_scenario(SCENARIO, language=lang)
+    scenario = parse_scenario(SCENARIO, language='ru')
 
     assert_equal(
         scenario.name,
@@ -113,12 +77,12 @@ def test_scenario_ru_from_string():
     )
     assert_equal(
         scenario.steps[0].hashes,
-        [
+        (
             {u'Название': u'Матан',
              u'Длительность': u'2 года'},
             {u'Название': u'Основы программирования',
              u'Длительность': u'1 год'},
-        ]
+        )
     )
 
 
@@ -127,8 +91,7 @@ def test_scenario_outline1_ru_from_string():
     Language: RU -> Scenario.from_string, with scenario outline, first case
     """
 
-    lang = Language('ru')
-    scenario = parse_scenario(SCENARIO_OUTLINE1, language=lang)
+    scenario = parse_scenario(SCENARIO_OUTLINE1, language='ru')
 
     assert_equal(
         scenario.name,
@@ -136,10 +99,10 @@ def test_scenario_outline1_ru_from_string():
     )
     assert_equal(
         scenario.outlines,
-        [
+        (
             {u'имя': u'Вася', u'возраст': '22'},
             {u'имя': u'Петя', u'возраст': '30'},
-        ]
+        )
     )
 
 
@@ -148,8 +111,7 @@ def test_feature_ru_from_string():
     Language: RU -> Feature.from_string
     """
 
-    lang = Language('ru')
-    feature = Feature.from_string(FEATURE, language=lang)
+    feature = Feature.from_string(FEATURE, language='ru')
 
     assert_equal(
         feature.name,
@@ -171,9 +133,9 @@ def test_feature_ru_from_string():
 
     assert_equal(
         scenario.steps[-1].hashes,
-        [
+        (
             {u'делимое': '100', u'делитель': '2', u'частное': '50'},
             {u'делимое': '28', u'делитель': '7', u'частное': '4'},
             {u'делимое': '0', u'делитель': '5', u'частное': '0'},
-        ]
+        )
     )
