@@ -1,20 +1,4 @@
 # -*- coding: utf-8 -*-
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test Gherkin parser.
 """
@@ -26,13 +10,13 @@ from __future__ import absolute_import
 # pylint:disable=redefined-builtin
 from builtins import zip
 # pylint:enable=redefined-builtin
-from future import standard_library
-standard_library.install_aliases()
+
+import tempfile
 
 from nose.tools import assert_equal, assert_raises
 
 from aloe.parser import Feature, Scenario, Background
-from aloe.exceptions import LettuceSyntaxError
+from aloe.exceptions import AloeSyntaxError
 
 FEATURE1 = """
 Feature: Rent movies
@@ -100,11 +84,11 @@ Feature: Big table
       | description                                                               |
       | this is such a huge description within a table, the maxlengh will be huge |
       | this is another description within a table                                |
-"""  # noqa
+"""
 
 FEATURE6 = """
 Feature: Big scenario outline
-  Scenario: Regular numbers
+  Scenario Outline: Regular numbers
     Given I do fill 'description' with '<value_two>'
   Examples:
     | value_two                                                               |
@@ -124,7 +108,7 @@ Feature: Big table
 
 FEATURE8 = """
 Feature: Big scenario outline
-  Scenario: big scenario outlines
+  Scenario Outline: big scenario outlines
     Given I do fill 'description' with '<value_two>'
 
   Examples:
@@ -135,7 +119,7 @@ Feature: Big scenario outline
 
 FEATURE9 = """
 Feature: Big scenario outline
-  Scenario: big scenario outlines
+  Scenario Outline: big scenario outlines
     Given I do fill 'description' with '<value_two>'
 
   Examples:
@@ -493,7 +477,7 @@ def test_feature_has_scenarios():
 
     feature = Feature.from_string(FEATURE1)
 
-    assert isinstance(feature.scenarios, list)
+    assert isinstance(feature.scenarios, tuple)
     assert len(feature.scenarios) == 3
 
     expected_names = [
@@ -506,8 +490,10 @@ def test_feature_has_scenarios():
         assert isinstance(scenario, Scenario)
         assert scenario.name == expected_name
 
-    assert feature.scenarios[1].steps[0].keys == \
+    assert_equal(
+        feature.scenarios[1].steps[0].keys,
         ('Name', 'Rating', 'New', 'Available')
+    )
 
     assert list(feature.scenarios[1].steps[0].hashes) == [
         {
@@ -680,20 +666,20 @@ def test_single_scenario_single_scenario():
 
     first_scenario = feature.scenarios[0]
 
-    assert first_scenario.tags == [
+    assert_equal(first_scenario.tags, (
         'many', 'other', 'basic', 'tags', 'here', ':)'
-    ]
+    ))
 
 
 def test_single_feature_single_tag():
     "All scenarios within a feature inherit the feature's tags"
     feature = Feature.from_string(FEATURE18)
 
-    assert feature.scenarios[0].tags == ['runme1', 'feature_runme']
+    assert feature.scenarios[0].tags == ('runme1', 'feature_runme')
 
-    assert feature.scenarios[1].tags == ['runme2', 'feature_runme']
+    assert feature.scenarios[1].tags == ('runme2', 'feature_runme')
 
-    assert feature.scenarios[2].tags == ['runme3', 'feature_runme']
+    assert feature.scenarios[2].tags == ('runme3', 'feature_runme')
 
 
 def test_single_scenario_many_scenarios():
@@ -702,23 +688,23 @@ def test_single_scenario_many_scenarios():
     feature = Feature.from_string(FEATURE13)
 
     first_scenario = feature.scenarios[0]
-    assert first_scenario.tags == ['runme']
+    assert first_scenario.tags == ('runme',)
 
     second_scenario = feature.scenarios[1]
-    assert second_scenario.tags == []
+    assert second_scenario.tags == ()
 
     third_scenario = feature.scenarios[2]
-    assert third_scenario.tags == ['slow']
+    assert third_scenario.tags == ('slow',)
 
     last_scenario = feature.scenarios[3]
-    assert last_scenario.tags == []
+    assert last_scenario.tags == ()
 
 
 def test_scenarios_with_extra_whitespace():
     "Make sure that extra leading whitespace is ignored"
     feature = Feature.from_string(FEATURE14)
 
-    assert_equal(type(feature.scenarios), list)
+    assert_equal(type(feature.scenarios), tuple)
     assert_equal(len(feature.scenarios), 1, "It should have 1 scenario")
     assert_equal(feature.name, "Extra whitespace feature")
 
@@ -732,34 +718,34 @@ def test_scenarios_parsing():
     feature = Feature.from_string(FEATURE15)
     scenarios_and_tags = [(s.name, s.tags) for s in feature.scenarios]
 
-    assert scenarios_and_tags == [
-        ('Bootstraping Redis role', []),
-        ('Restart scalarizr', []),
-        ('Rebundle server', [u'rebundle']),
-        ('Use new role', [u'rebundle']),
-        ('Restart scalarizr after bundling', [u'rebundle']),
-        ('Bundling data', []),
-        ('Modifying data', []),
-        ('Reboot server', []),
-        ('Backuping data on Master', []),
-        ('Setup replication', []),
-        ('Restart scalarizr in slave', []),
-        ('Slave force termination', []),
-        ('Slave delete EBS', [u'ec2']),
-        ('Setup replication for EBS test', [u'ec2']),
-        ('Writing on Master, reading on Slave', []),
-        ('Slave -> Master promotion', []),
-        ('Restart farm', [u'restart_farm']),
-    ]
+    assert_equal(scenarios_and_tags, [
+        ('Bootstraping Redis role', ()),
+        ('Restart scalarizr', ()),
+        ('Rebundle server', ('rebundle',)),
+        ('Use new role', ('rebundle',)),
+        ('Restart scalarizr after bundling', ('rebundle',)),
+        ('Bundling data', ()),
+        ('Modifying data', ()),
+        ('Reboot server', ()),
+        ('Backuping data on Master', ()),
+        ('Setup replication', ()),
+        ('Restart scalarizr in slave', ()),
+        ('Slave force termination', ()),
+        ('Slave delete EBS', ('ec2',)),
+        ('Setup replication for EBS test', ('ec2',)),
+        ('Writing on Master, reading on Slave', ()),
+        ('Slave -> Master promotion', ()),
+        ('Restart farm', ('restart_farm',)),
+    ])
 
 
 def test_scenarios_with_special_characters():
     "Make sure that regex special characters in the scenario names are ignored"
     feature = Feature.from_string(FEATURE19)
 
-    assert feature.scenarios[0].tags == ['runme1']
+    assert feature.scenarios[0].tags == ('runme1',)
 
-    assert feature.scenarios[1].tags == ['runme2']
+    assert feature.scenarios[1].tags == ('runme2',)
 
 
 def test_background_parsing_with_mmf():
@@ -777,7 +763,7 @@ def test_background_parsing_with_mmf():
     step1, step2 = feature.background.steps
     assert step1.sentence == \
         'Given I have the following movies in my database:'
-    assert step1.hashes == [
+    assert_equal(step1.hashes, (
         {
             u'Available': u'6',
             u'Rating': u'4 stars',
@@ -790,14 +776,14 @@ def test_background_parsing_with_mmf():
             u'Name': u'Iron Man 2',
             u'New': u'yes',
         },
-    ]
+    ))
 
     assert step2.sentence == \
         'And the following clients:'
-    assert step2.hashes == [
+    assert_equal(step2.hashes, (
         {u'Name': u'John Doe'},
         {u'Name': u'Foo Bar'},
-    ]
+    ))
 
 
 def test_background_parsing_without_mmf():
@@ -812,7 +798,7 @@ def test_background_parsing_without_mmf():
     step1, step2 = feature.background.steps
     assert step1.sentence == \
         'Given I have the following movies in my database:'
-    assert step1.hashes == [
+    assert_equal(step1.hashes, (
         {
             u'Available': u'6',
             u'Rating': u'4 stars',
@@ -825,35 +811,77 @@ def test_background_parsing_without_mmf():
             u'Name': u'Iron Man 2',
             u'New': u'yes',
         },
-    ]
-    assert step1.table == [
-        ['Name', 'Rating', 'New', 'Available'],
-        ['Matrix Revolutions', '4 stars', 'no', '6'],
-        ['Iron Man 2', '5 stars', 'yes', '11'],
-    ]
+    ))
+    assert_equal(step1.table, (
+        ('Name', 'Rating', 'New', 'Available'),
+        ('Matrix Revolutions', '4 stars', 'no', '6'),
+        ('Iron Man 2', '5 stars', 'yes', '11'),
+    ))
 
     assert step2.sentence == \
         'And the following clients:'
-    assert step2.hashes == [
+    assert_equal(step2.hashes, (
         {u'Name': u'John Doe'},
         {u'Name': u'Foo Bar'},
-    ]
-    assert step2.table == [
-        ['Name'],
-        ['John Doe'],
-        ['Foo Bar'],
-    ]
+    ))
+    assert_equal(step2.table, (
+        ('Name',),
+        ('John Doe',),
+        ('Foo Bar',),
+    ))
 
 
 def test_syntax_error_for_scenarios_with_no_name():
     ("Trying to parse features with unnamed "
      "scenarios will cause a syntax error")
-    with assert_raises(LettuceSyntaxError) as error:
+    with assert_raises(AloeSyntaxError) as error:
         Feature.from_string(FEATURE20)
 
-    assert error.exception.msg == \
-        'Syntax error at: None\n' \
-        '3:5 Scenario must have a name'
+    assert_equal(
+        error.exception.msg,
+        "Syntax error at: None\n"
+        "3:5 Scenario must have a name"
+    )
+
+
+def test_syntax_error_malformed_feature():
+    """Parsing a malformed feature causes a syntax error."""
+
+    with assert_raises(AloeSyntaxError) as error:
+        Feature.from_string("""
+PARSE ERROR
+""")
+
+    # pylint:disable=line-too-long
+    assert_equal(error.exception.msg, '\n'.join((
+        "Syntax error at: None",
+        "Parser errors:",
+        "(2:1): expected: #Language, #TagLine, #FeatureLine, #Comment, #Empty, got 'PARSE ERROR'",
+        "(3:0): unexpected end of file, expected: #Language, #TagLine, #FeatureLine, #Comment, #Empty",
+    )))
+    # pylint:enable=line-too-long
+
+
+def test_syntax_error_malformed_feature_from_file():
+    """Parsing a malformed feature in a filecauses a syntax error."""
+
+    with tempfile.NamedTemporaryFile() as feature_file:
+        feature_file.write(b"""
+PARSE ERROR
+""")
+        feature_file.flush()
+
+        with assert_raises(AloeSyntaxError) as error:
+            Feature.from_file(feature_file.name)
+
+        # pylint:disable=line-too-long
+        assert_equal(error.exception.msg, '\n'.join((
+            "Syntax error at: {filename}",
+            "Parser errors:",
+            "(2:1): expected: #Language, #TagLine, #FeatureLine, #Comment, #Empty, got 'PARSE ERROR'",
+            "(3:0): unexpected end of file, expected: #Language, #TagLine, #FeatureLine, #Comment, #Empty",
+        )).format(filename=feature_file.name))
+        # pylint:enable=line-too-long
 
 
 def test_scenario_post_email():
@@ -864,8 +892,8 @@ def test_scenario_post_email():
     feature = Feature.from_string(FEATURE21)
     scenario1, scenario2 = feature.scenarios
 
-    assert scenario1.tags == []
-    assert scenario2.tags == ['tag']
+    assert scenario1.tags == ()
+    assert scenario2.tags == ('tag',)
 
 
 def test_feature_first_scenario_tag_extraction():
@@ -873,7 +901,7 @@ def test_feature_first_scenario_tag_extraction():
      "belonging to the first scenario")
     feature = Feature.from_string(FEATURE22)
 
-    assert feature.scenarios[0].tags == ['onetag']
+    assert feature.scenarios[0].tags == ('onetag',)
 
 
 def test_feature_first_scenario_tags_extraction():
@@ -882,4 +910,4 @@ def test_feature_first_scenario_tags_extraction():
     feature = Feature.from_string(FEATURE23)
 
     assert feature.scenarios[0].tags == \
-        ['onetag', 'another', '$%^&even-weird_chars']
+        ('onetag', 'another', '$%^&even-weird_chars')
