@@ -1,20 +1,4 @@
 # -*- coding: utf-8 -*-
-# Aloe - Cucumber runner for Python based on Lettuce and Nose
-# Copyright (C) <2010-2012>  Gabriel Falcão <gabriel@nacaolivre.org>
-#
-# This program is free software: you can redistribute it and/or modify
-# it under the terms of the GNU General Public License as published by
-# the Free Software Foundation, either version 3 of the License, or
-# (at your option) any later version.
-#
-# This program is distributed in the hope that it will be useful,
-# but WITHOUT ANY WARRANTY; without even the implied warranty of
-# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-# GNU General Public License for more details.
-#
-# You should have received a copy of the GNU General Public License
-# along with this program.  If not, see <http://www.gnu.org/licenses/>.
-
 """
 Test step and callback registry.
 """
@@ -23,16 +7,11 @@ from __future__ import unicode_literals
 from __future__ import print_function
 from __future__ import division
 from __future__ import absolute_import
-from future import standard_library
-standard_library.install_aliases()
 
-import re
 import unittest
 
 from nose.tools import (
     assert_equal,
-    assert_in,
-    assert_not_in,
     assert_raises,
 )
 
@@ -42,14 +21,42 @@ from aloe.registry import (
     PriorityClass,
     StepDict,
 )
-from aloe.exceptions import StepLoadingError
+from aloe.exceptions import (
+    StepLoadingError,
+    undefined_step,
+)
 
 from tests.utils import appender, before_after
 
 
+class FakeStep(object):
+    """A fake step object to use in matching."""
+
+    def __init__(self, sentence):
+        self.sentence = sentence
+
+
+def assert_matches(step_dict, sentence, func_args):
+    """
+    Assert what a given sentence matches in a step dictionary.
+
+    :param StepDict step_dict: Step dictionary to check
+    :param sentence str: Sentence to match
+    :param func_args (callable, tuple, dict): Expected function and arguments
+    """
+
+    assert_equal(step_dict.match_step(FakeStep(sentence)), func_args)
+
+
+def assert_no_match(step_dict, sentence):
+    """Assert that no match is found for a sentence in a step dictionary."""
+
+    assert_matches(step_dict, sentence, (undefined_step, (), {}))
+
+
 def test_StepDict_raise_StepLoadingError_if_first_argument_is_not_a_regex():
     """
-    lettuce.STEP_REGISTRY.load(step, func) should raise an error if step is
+    aloe.STEP_REGISTRY.load(step, func) should raise an error if step is
     not a regex
     """
     steps = StepDict()
@@ -59,7 +66,7 @@ def test_StepDict_raise_StepLoadingError_if_first_argument_is_not_a_regex():
 
 def test_StepDict_can_load_a_step_composed_of_a_regex_and_a_function():
     """
-    lettuce.STEP_REGISTRY.load(step, func) append item(step, func) to
+    aloe.STEP_REGISTRY.load(step, func) append item(step, func) to
     STEP_REGISTRY
     """
     steps = StepDict()
@@ -70,14 +77,46 @@ def test_StepDict_can_load_a_step_composed_of_a_regex_and_a_function():
     step = "a step to test"
     steps.load(step, func)
 
-    step = re.compile(step, re.I | re.U)
-    assert_in(step, steps)
-    assert_equal(steps[step], func)
+    assert_matches(steps, step, (func, (), {}))
+
+
+def test_replacing_step():
+    """
+    Test registering a different step with the same sentence.
+    """
+
+    def func1():
+        """First function to register as a step."""
+        pass
+
+    def func2():
+        """Second function to register as a step."""
+        pass
+
+    steps = StepDict()
+
+    # This has to be more than re._MAXCACHE; currently 100 on Python 2.7 and
+    # 512 on Python 3.5
+    step_count = 1024
+
+    sentence = "sentence {0}".format
+
+    # Register some steps
+    for num in range(step_count):
+        steps.load(sentence(num), func1)
+
+    # Register the same steps again
+    for num in range(step_count):
+        steps.load(sentence(num), func2)
+
+    # func2 should have replaced func1 everywhere
+    for num in range(step_count):
+        assert_matches(steps, sentence(num), (func2, (), {}))
 
 
 def test_StepDict_load_a_step_return_the_given_function():
     """
-    lettuce.STEP_REGISTRY.load(step, func) returns func
+    aloe.STEP_REGISTRY.load(step, func) returns func
     """
     steps = StepDict()
 
@@ -89,7 +128,7 @@ def test_StepDict_load_a_step_return_the_given_function():
 
 def test_StepDict_can_extract_a_step_sentence_from_function_name():
     """
-    lettuce.STEP_REGISTRY.extract_sentence(func) parse func name and return
+    aloe.STEP_REGISTRY.extract_sentence(func) parse func name and return
     a sentence
     """
     steps = StepDict()
@@ -101,7 +140,7 @@ def test_StepDict_can_extract_a_step_sentence_from_function_name():
 
 def test_StepDict_can_extract_a_step_sentence_from_function_doc():
     """
-    lettuce.STEP_REGISTRY.extract_sentence(func) parse func doc and return
+    aloe.STEP_REGISTRY.extract_sentence(func) parse func doc and return
     a sentence
     """
     steps = StepDict()
@@ -114,7 +153,7 @@ def test_StepDict_can_extract_a_step_sentence_from_function_doc():
 
 def test_StepDict_can_load_a_step_from_a_function():
     """
-    lettuce.STEP_REGISTRY.load_func(func) append item(step, func) to
+    aloe.STEP_REGISTRY.load_func(func) append item(step, func) to
     STEP_REGISTRY
     """
     steps = StepDict()
@@ -124,14 +163,12 @@ def test_StepDict_can_load_a_step_from_a_function():
 
     steps.load_func(a_step_to_test)
 
-    expected_sentence = re.compile("A step to test", re.I | re.U)
-    assert_in(expected_sentence, steps)
-    assert_equal(steps[expected_sentence], a_step_to_test)
+    assert_matches(steps, "A step to test", (a_step_to_test, (), {}))
 
 
 def test_StepDict_can_load_steps_from_an_object():
     """
-    lettuce.STEP_REGISTRY.load_steps(obj) append all obj methods to
+    aloe.STEP_REGISTRY.load_steps(obj) append all obj methods to
     STEP_REGISTRY
     """
     steps = StepDict()
@@ -149,17 +186,13 @@ def test_StepDict_can_load_steps_from_an_object():
     step_list = LotsOfSteps()
     steps.load_steps(step_list)
 
-    expected_sentence1 = re.compile("Step 1", re.I | re.U)
-    expected_sentence2 = re.compile("Doing something", re.I | re.U)
-    assert_in(expected_sentence1, steps)
-    assert_in(expected_sentence2, steps)
-    assert_equal(steps[expected_sentence1], step_list.step_1)
-    assert_equal(steps[expected_sentence2], step_list.step_2)
+    assert_matches(steps, "Step 1", (step_list.step_1, (), {}))
+    assert_matches(steps, "Doing something", (step_list.step_2, (), {}))
 
 
 def test_StepDict_can_exclude_methods_when_load_steps():
     """
-    lettuce.STEP_REGISTRY.load_steps(obj) don't load exluded attr in
+    aloe.STEP_REGISTRY.load_steps(obj) don't load exluded attr in
     STEP_REGISTRY
     """
     steps = StepDict()
@@ -178,15 +211,13 @@ def test_StepDict_can_exclude_methods_when_load_steps():
     step_list = LotsOfSteps()
     steps.load_steps(step_list)
 
-    expected_sentence1 = re.compile("Step 1", re.I | re.U)
-    expected_sentence2 = re.compile("Doing something", re.I | re.U)
-    assert_not_in(expected_sentence1, steps)
-    assert_in(expected_sentence2, steps)
+    assert_no_match(steps, "Step 1")
+    assert_matches(steps, "Doing something", (step_list.step_2, (), {}))
 
 
 def test_StepDict_can_exclude_callable_object_when_load_steps():
     """
-    lettuce.STEP_REGISTRY.load_steps(obj) don't load callable objets in
+    aloe.STEP_REGISTRY.load_steps(obj) don't load callable objets in
     STEP_REGISTRY
     """
     steps = StepDict()
@@ -212,17 +243,12 @@ def test_unload_reload():
     def step():  # pylint:disable=missing-docstring
         pass
 
-    class StepDefinition(object):
-        """A step definition object to match."""
-        sentence = 'My step 1'
-
     steps = StepDict()
 
     # Load
     steps.step(r'My step (\d)')(step)
 
-    assert len(steps) == 1
-    assert steps.match_step(StepDefinition) == (step, ('1',), {})
+    assert_matches(steps, "My step 1", (step, ('1',), {}))
 
     # Members added to step by registering it
     # pylint:disable=no-member
@@ -230,18 +256,17 @@ def test_unload_reload():
     # Unload
     step.unregister()
 
-    assert len(steps) == 0
+    assert_no_match(steps, "My step 1")
 
     # Should be a no-op
     step.unregister()
 
-    assert len(steps) == 0
+    assert_no_match(steps, "My step 1")
 
     # Reload
     steps.step(step.sentence)(step)
 
-    assert len(steps) == 1
-    assert steps.match_step(StepDefinition) == (step, ('1',), {})
+    assert_matches(steps, "My step 1", (step, ('1',), {}))
 
 
 class CallbackDictTest(unittest.TestCase):
